import React from 'react';
declare type SEOProps = {
    title?: string;
    canonical?: string;
    /**
     * Set `robots` only when you don't want search engines to index the page.
     */
    robots?: 'noindex' | 'nofollow' | 'noindex, nofollow' | 'index, follow';
    description?: string;
    /**
     * Truncate after maxDescriptionCharacters. Default value is 150.
     * (Google generally truncates descritpion to ~155–160 characters https://moz.com/learn/seo/meta-description )
     */
    maxDescriptionCharacters?: number;
    twitter?: {
        /**
         * Twitter card type
         * https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/abouts-cards
         */
        card?: 'summary' | 'summary_large_image' | 'player' | 'app';
        /**
         * Twitter username starting with @
         */
        site?: string;
    };
    /**
     * Additional meta tags.
     * Setting same value for `key` property between `<DefaultSeo />` and `<PageSeo />` will override the default meta tag (Otherwise both of them will be rendered)
     */
    customMetaTags?: Record<string, string>[];
    /**
     * Additional link tags.
     * Setting same value for `key` property between `<DefaultSeo />` and `<PageSeo />` will override the default meta tag (Otherwise both of them will be rendered)
     */
    customLinkTags?: Record<string, string>[];
    og?: {
        title?: string;
        description?: string;
        url?: string;
        type?: 'article' | 'book' | 'website' | 'profile';
        /**
         * URL for og:image
         */
        image?: string;
        siteName?: string;
    };
};
declare const SEO: React.VFC<SEOProps>;
export default SEO;
